﻿using System;
using System.Drawing;
using System.Windows.Forms;

namespace ELTE.Forms.ColorGrid
{
    public partial class GridForm : Form
    {
        private Random _Random; // véletlenszám generátor
        private GridButton[,] _Buttons; // gombok mátrixa    

        public GridForm()
        {
            InitializeComponent();

            _Random = new Random();
        }

        private void ButtonSize_Click(object sender, EventArgs e)
        {
            if (_Buttons != null)
            // ha már vannak gombok az ablakban, töröljük azokat
            {
                foreach (Button button in _Buttons)
                    _TableLayoutGrid.Controls.Remove(button);
                // a törlés pontosabban azt jelenti, hogy levesszük őket a tartalmazó vezérlőről
            }
            _Buttons = new GridButton[Convert.ToInt32(_NumericRows.Value), Convert.ToInt32(_NumericColumns.Value)];
            // új mátrix létrehozása

            // be kell állítani a táblaelhelyezés méreteit
            _TableLayoutGrid.RowCount = Convert.ToInt32(_NumericRows.Value);
            _TableLayoutGrid.ColumnCount = Convert.ToInt32(_NumericColumns.Value);

            for (Int32 i = 0; i < _NumericRows.Value; i++) // addig megyünk, amíg a számlálók mondják
            {
                for (Int32 j = 0; j < _NumericColumns.Value; j++)
                {
                    _Buttons[i, j] = new GridButton(i, j);
                    _Buttons[i, j].BackColor = Color.White;  // beállítjuk a kezdőszínét
                    _Buttons[i, j].Dock = DockStyle.Fill; // kitöltésre állítjuk
                    _Buttons[i, j].Click += new EventHandler(GridButton_Click); // eseménykezelő társítás
                    _TableLayoutGrid.Controls.Add(_Buttons[i, j], j, i); // hozzáadjuk a táblapanel vezérlőihez
                }
            }

            // létre kell hozni a megfelelő stípusokat a soroknak és oszlopoknak
            _TableLayoutGrid.RowStyles.Clear();
            _TableLayoutGrid.ColumnStyles.Clear();

            for (Int32 i = 0; i < _NumericRows.Value; i++)
            {
                _TableLayoutGrid.RowStyles.Add(new RowStyle(SizeType.Percent, 1 / Convert.ToSingle(_NumericRows.Value)));
                // a sorok és oszlopok egyenlően, arányosan méreteződnek
            }
            for (Int32 j = 0; j < _NumericColumns.Value; j++)
            {
                _TableLayoutGrid.ColumnStyles.Add(new ColumnStyle(SizeType.Percent, 1 / Convert.ToSingle(_NumericColumns.Value)));
            }
        }

        private void GridButton_Click(object sender, EventArgs e)
        {
            Int32 x = (sender as GridButton).GridX; // rácskoordináták kiolvasása
            Int32 y = (sender as GridButton).GridY;
            Color color = Color.FromArgb(_Random.Next(256), _Random.Next(256), _Random.Next(256)); // ú, véletlenszín generálás
            
            for (Int32 i = 0; i < _Buttons.GetLength(0); i++)
            {
                _Buttons[i, y].BackColor = color; // átszínezés
            }
            for (Int32 j = 0; j < _Buttons.GetLength(1); j++)
            {
                _Buttons[x, j].BackColor = color;
            }
        }
    }
}
