﻿using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

namespace ELTE.Forms.MotionPicture
{
    public partial class MotionForm : Form
    {
        private PictureBox[] _SmallPictures; // kis képek megjelenítésére
        private Image[] _Images; // teljes képek tárolása
        private Int32 _CurrentIndex; // aktuális kép
        private Timer _Timer; // időzítő

        public MotionForm()
        {
            InitializeComponent();
            _FolderBrowserDialog.SelectedPath = Path.GetDirectoryName(Application.ExecutablePath);

            _Timer = new Timer(); // időzítő inicializálása
            _Timer.Interval = 1000; // időzítő intervalluma ezredmásodpercben
            _Timer.Tick += new EventHandler(Timer_Tick); // időzítő eseménykezelője
        }

        private void Timer_Tick(object sender, EventArgs e)
        {
            if (_Images != null && _Images.Length > 0) // mutatott kép léptetése
                _CurrentIndex = (_CurrentIndex + 1) % _Images.Length;
            else
                _CurrentIndex = 0;
            ReloadImages();
        }

        private void LoadButton_Click(object sender, EventArgs e)
        {
            if (_FolderBrowserDialog.ShowDialog() == DialogResult.OK) // ha OK-val zárták le a dialógusablakot
            { 
                String[] files = Directory.GetFiles(_FolderBrowserDialog.SelectedPath, "*.jpg"); 
                // könyvtár jpg kiterjesztésű fájljainak listázása

                _Images = new Image[files.Length]; // a képek száma megegyezik a fájlok számával
                for (Int32 i = 0; i < files.Length; i++)
                {
                    try
                    {
                        _Images[i] = Image.FromFile(files[i]); // kép betöltése
                    }
                    catch (ArgumentException) // ha a fájl nem kép
                    {
                        _Images[i] = null;
                    }
                }
                _CurrentIndex = 0;
                _NumericSmallImageCount.Value = _NumericSmallImageCount.Maximum = _Images.Length; // a maximális szám a képek számától függ
                ReloadPictureBoxes();
                ReloadImages();
            }
        }

        private void ReloadPictureBoxes() // kis képeket tartalmazó képmegjelenítők cseréje
        {
            if (_SmallPictures != null)
                foreach (var smallPicture in _SmallPictures)
                    Controls.Remove(smallPicture); // régi képmegjelenítők levétele

            _SmallPictures = new PictureBox[Convert.ToInt32(_NumericSmallImageCount.Value - 1)];
            for (Int32 i = 0; i < _SmallPictures.Length; i++)
            {
                _SmallPictures[i] = new PictureBox(); // új képmegjelenítők létrehozása
                _SmallPictures[i].Location = new Point(2 + (i % 12) * 25, 370 + (i / 12) * 25);
                _SmallPictures[i].Size = new Size(25, 25);
                _SmallPictures[i].BorderStyle = BorderStyle.FixedSingle; // keret
                _SmallPictures[i].SizeMode = PictureBoxSizeMode.StretchImage; // nyújtás

                Controls.Add(_SmallPictures[i]); // vezérlő felvétele
            }
        }

        private void ReloadImages()  // képek újratöltése sorszámváltásnál
        {
            _MainPictureBox.Image = _Images[_CurrentIndex];
            for (Int32 i = 0; i < _SmallPictures.Length; i++)
                _SmallPictures[i].Image = _Images[(_CurrentIndex + i) % _Images.Length];
        }

        private void StartStopButton_Click(object sender, EventArgs e)
        {
            if (_Timer.Enabled) // időzítő kapcsolása
                _Timer.Stop();
            else
                _Timer.Start();
        }

        private void NumericSmallImageCount_ValueChanged(object sender, EventArgs e)
        {
            _Timer.Interval = Convert.ToInt32(1000 / _NumericSmallImageCount.Value); // időzítő állítása
            ReloadPictureBoxes();
            ReloadImages();
        }
    }
}
