﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ELTE.Forms.RandomGenerator
{
    public partial class MainForm : Form
    {
        private Timer _Timer; // időzítő a véletlengeneráláshoz
        private Random _ThesisGenerator; // véletlenszám generátor
        private Int32 _ThesisCount; // a tételek száma
        private Int32 _PeriodLength; // periódus hossza
        private List<Int32> _History; // a periódosbeli, korábban húzott számok

        public MainForm()
        {
            InitializeComponent();

            _History = new List<Int32>();
            _ThesisCount = 0;
            _PeriodLength = 0;
            _ThesisGenerator = new Random(); // időfüggő véletlenszám inicializálás

            _Timer = new Timer();
            _Timer.Interval = 100; // 100/1000 másodpercenként történő futtatás
            _Timer.Tick += new EventHandler(Timer_Tick); // időzített esemény társítása
        }

        private void Timer_Tick(object sender, EventArgs e)
        {
            Int32 number = _ThesisGenerator.Next(1, _ThesisCount + 1); // új szám generálása 1 és a tételszám között
            while (_History.Contains(number)) // ha a szám szerepel a korábbiak között
                number = _ThesisGenerator.Next(1, _ThesisCount + 1); // akkor új generálása

            _TextNumber.Text = number.ToString();
        }

        private void ButtonStart_Click(object sender, EventArgs e)
        {
            if (_ThesisCount == 0)
            {
                MessageBox.Show("Még nem adtál meg maximumértéket!");
                return;
            }
            if (!_Timer.Enabled)
            {
                if (_History.Count == _PeriodLength) // ha elértük a perióduskorlátot
                    _History.RemoveAt(0); // töröljük a legrégebbi elemet
                _Timer.Start();
                _ButtonStart.Text = "STOP";
            }
            else 
            {
                _History.Add(Int32.Parse(_TextNumber.Text));
                _Timer.Stop();
                _ButtonStart.Text = "START";
            }
        }

        private void ButtonSet_Click(object sender, EventArgs e)
        {
            SettingsForm f = new SettingsForm();
            if (_ThesisCount > 0) // ha már vannak korábbi értékek
            {
                f.ThesisCount = _ThesisCount; // átadjuk őket a beállító ablaknak
                f.PeriodLength = _PeriodLength;
                f.LoadHistory(_History);
            }
            f.ShowDialog(); // dialógusablak
            _ThesisCount = f.ThesisCount; // visszavesszük az új értékeket
            _PeriodLength = f.PeriodLength;
        }
    }
}
