﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ELTE.Forms.RandomGenerator
{
    /// <summary>
    /// Beállítások kezelőablakának típusa.
    /// </summary>
    public partial class SettingsForm : Form
    {
        private List<Int32> _History; // a korábban húzott tételeket tartalmazó lista

        /// <summary>
        /// Tételek számának lekérdezése.
        /// </summary>
        public Int32 ThesisCount
        {
            get { return Convert.ToInt32(_NumericThesisCount.Value); }
            set { _NumericThesisCount.Value = value; }
        }
        /// <summary>
        /// Periódus hosszának lekrédezése.
        /// </summary>
        public Int32 PeriodLength
        {
            get { return Convert.ToInt32(_NumericPeriodLength.Value); }
            set { _NumericPeriodLength.Value = value; }
        }

        public SettingsForm()
        {
            InitializeComponent();
        }

        public void LoadHistory(List<Int32> history)
        {
            _History = history;

            _CheckedListBox.ItemCheck -= _CheckedListBox_ItemCheck;
            // számok betöltése a listába
            for (Int32 i = 1; i <= _NumericThesisCount.Value; i++)
            {
                _CheckedListBox.Items.Add(i, _History.Contains(i));
                // ha szerepel a korábban kíhúzottak között, akkor bejelöljük
            }
            _CheckedListBox.ItemCheck += _CheckedListBox_ItemCheck;

        }

        private void ButtonOk_Click(object sender, EventArgs e)
        {
            foreach (Int32 val in _CheckedListBox.Items)
            {
                // minden olyan elemnél, ahol el lett távolítva a kiválasztás
                if (!_CheckedListBox.CheckedItems.Contains(val) && _History.Contains(val))
                {
                    _History.Remove(val);
                    // töröljük a korábban húzottak közül
                }
            }
            Close();
        }

        private void NumericNumber_ValueChanged(object sender, EventArgs e)
        {
            if (_NumericPeriodLength.Value >= _NumericThesisCount.Value)
                _NumericPeriodLength.Value = _NumericThesisCount.Value - 1;
            _NumericPeriodLength.Maximum = _NumericThesisCount.Value - 1;
            // a periódus értéke nem lehet nagyobb a maximális értéknél
        }

        private void _CheckedListBox_ItemCheck(object sender, ItemCheckEventArgs e)
        {
            if (e.CurrentValue == CheckState.Unchecked)
            {
                MessageBox.Show("You can only uncheck itemts.", "Setting error", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                e.NewValue = CheckState.Unchecked;
            }
        }
    }
}
